==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/is.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Fyrsta-skiptis-leiðarvísir",
    "Add your profile information! For example your email is needed to reset your password." : "Bættu við notandaupplýsingarnar þínar! Til dæmis þarftu að setja inn tölvupóstfangið þitt til að geta endurstillt lykilorð.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Bættu við notandaupplýsingarnar þínar! Settu auðkennismynd og fullt nafn svo auðveldara verði að nota marga eiginleika.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Bættu við notandaupplýsingarnar þínar! Settu inn fullt nafn svo auðveldara verði að nota marga eiginleika.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Bættu við notandaupplýsingarnar þínar! Settu inn auðkennismynd svo auðveldara verði að nota marga eiginleika.",
    "Get the apps to sync your files" : "Náðu í forrit til að samstilla skrárnar þínar",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "%s veitir þér aðgang að skránum þínum hvar sem þú ert. Tengiforritin okkar fyrir tölvur og snjalltæki eru fáanleg fyrir flest algengustu stýrikerfi án nokkurs kostnaðar.",
    "Desktop client" : "Skjáborðsforrit",
    "Android app" : "Android-forrit",
    "iOS app" : "iOS-forrit",
    "Setup sync clients using an <a href=\"\">app password</a>. That way you can make sure you are able to revoke access in case you loose that device." : "Settu upp samstillingaforrit með <a href=\"\">lykilorði forrits</a>. Þannig geturðu gengið úr skugga um að þú getir afturkallað aðganginn ef svo kynni að fara að þú týndir viðkomandi tæki.",
    "Connect other apps to %s" : "Tengdu önnur forrit við %s",
    "Besides the sync clients you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "Fyrir utan samstillingaforritin geturðu tengt hvert það forrit sem styður WebDAV/CalDAV/CardDAV samskiptamátana við %s.",
    "Connect your calendar" : "Tengdu dagatalið þitt",
    "Connect your contacts" : "Tengdu tengiliðalistana þína",
    "Access files via WebDAV" : "Nálgastu skrár í gegnum WebDAV",
    "The first run wizard helps you to get started with %s." : "Fyrsta-skiptis leiðarvísirinn hjálpar þér að komast í gang með %s.",
    "Show first run wizard again" : "Birta fyrsta-skiptis-leiðarvísinn aftur",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "Fáðu aðgang að og deildu skrám, dagatölum, tengiliðum, tölvupósti og ýmsu fleiru, á hvaða tæki sem er og á þínum eigin forsendum",
    "Connect your desktop apps to %s" : "Tengdu skjáborðsforritin við %s",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>." : "Ítarlegri upplýsingar er að finna í <a target=\"_blank\" href=\"%s\">hjálparskjölum</a> og á <a target=\"_blank\" href=\"%s\">vefsvæðinu</a> okkar.",
    "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!" : "Ef þér líkar Nextcloud,  <a href=\"mailto:?subject=Nextcloud &body=Nextcloud er frábær frjáls hugbúnaður til að samstilla og deila skránum þínum með öðrum. Þú færð það án nokkurra skuldbindinga frá https://nextcloud.com\"> mæltu með því við vini þína</a> og <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">leggðu þitt af mörkum</a>!",
    "Connect your Calendar" : "Tengdu dagatalið þitt",
    "Connect your Contacts" : "Tengdu tengiliðalistana þína",
    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "Ef þú vilt styðja við verkefnið {contributeopen}taktu þátt í þróuninni {linkclose} eða {contributeopen}láttu orð út ganga{linkclose}!",
    "Show First Run Wizard again" : "Birta Fyrsta-skiptis-leiðarvísinn aftur"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/is.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Fyrsta-skiptis-leiðarvísir",
    "Add your profile information! For example your email is needed to reset your password." : "Bættu við notandaupplýsingarnar þínar! Til dæmis þarftu að setja inn tölvupóstfangið þitt til að geta endurstillt lykilorð.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Bættu við notandaupplýsingarnar þínar! Settu auðkennismynd og fullt nafn svo auðveldara verði að nota marga eiginleika.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Bættu við notandaupplýsingarnar þínar! Settu inn fullt nafn svo auðveldara verði að nota marga eiginleika.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Bættu við notandaupplýsingarnar þínar! Settu inn auðkennismynd svo auðveldara verði að nota marga eiginleika.",
    "About" : "Um hugbúnaðinn",
    "Get the apps to sync your files" : "Náðu í forrit til að samstilla skrárnar þínar",
    "Desktop client" : "Skjáborðsforrit",
    "Android app" : "Android-forrit",
    "iOS app" : "iOS-forrit",
    "Connect your desktop apps to %s" : "Tengdu skjáborðsforritin við %s",
    "Connect your calendar" : "Tengdu dagatalið þitt",
    "Connect your contacts" : "Tengdu tengiliðalistana þína",
    "Access files via WebDAV" : "Nálgastu skrár í gegnum WebDAV",
    "Get help" : "Til að fá hjálp",
    "Get more information" : "Til að fá frekari upplýsingar",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "%s veitir þér aðgang að skránum þínum hvar sem þú ert. Tengiforritin okkar fyrir tölvur og snjalltæki eru fáanleg fyrir flest algengustu stýrikerfi án nokkurs kostnaðar.",
    "Connect other apps to %s" : "Tengdu önnur forrit við %s",
    "Besides the sync clients you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "Fyrir utan samstillingaforritin geturðu tengt hvert það forrit sem styður WebDAV/CalDAV/CardDAV samskiptamátana við %s.",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "Fáðu aðgang að og deildu skrám, dagatölum, tengiliðum, tölvupósti og ýmsu fleiru, á hvaða tæki sem er og á þínum eigin forsendum",
    "Connect your Calendar" : "Tengdu dagatalið þitt",
    "Connect your Contacts" : "Tengdu tengiliðalistana þína",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>." : "Ítarlegri upplýsingar er að finna í <a target=\"_blank\" href=\"%s\">hjálparskjölum</a> og á <a target=\"_blank\" href=\"%s\">vefsvæðinu</a> okkar.",
    "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!" : "Ef þér líkar Nextcloud,  <a href=\"mailto:?subject=Nextcloud &body=Nextcloud er frábær frjáls hugbúnaður til að samstilla og deila skránum þínum með öðrum. Þú færð það án nokkurra skuldbindinga frá https://nextcloud.com\"> mæltu með því við vini þína</a> og <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">leggðu þitt af mörkum</a>!",
    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "Ef þú vilt styðja við verkefnið {contributeopen}taktu þátt í þróuninni {linkclose} eða {contributeopen}láttu orð út ganga{linkclose}!",
    "Show First Run Wizard again" : "Birta Fyrsta-skiptis-leiðarvísinn aftur"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
